# MoneyKit

MoneyKit is the next generation connection for the world's money.

This is an autogenerated python SDK for OpenFGA. It provides a wrapper around the [MoneyKit API definition](https://docs.moneykit.com).

## Installation & Usage

### Poetry

Install via [Poetry](https://python-poetry.org/).

```sh
poetry add moneykit
```

Then import the package:
```python
import moneykit
```

### pip install

```sh
pip install moneykit
```

Then import the package:
```python
import moneykit
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import moneykit
from moneykit.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.moneykit.com
# See configuration.py for a list of all supported configuration parameters.
configuration = moneykit.Configuration(
    host = "https://api.moneykit.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: HTTPBasic
configuration = moneykit.Configuration(
    username = os.environ["USERNAME"],
    password = os.environ["PASSWORD"]
)


# Enter a context with an instance of the API client
with moneykit.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = moneykit.AccessTokenApi(api_client)
    moneykit_version = '2023-02-18' # str |  (optional) (default to '2023-02-18')
    grant_type = 'grant_type_example' # str | Token grant type. Only `client_credentials` supported. (optional)
    scope = '' # str | Actions to be allowed for this token, given as one or more strings separated by spaces.             If omitted, all actions allowed for your application will be granted to this token. (optional) (default to '')
    client_id = 'client_id_example' # str | Your application's MoneyKit client ID. (optional)
    client_secret = 'client_secret_example' # str | Your application's MoneyKit client secret. (optional)

    try:
        # /auth/token
        api_response = api_instance.generate_access_token(moneykit_version=moneykit_version, grant_type=grant_type, scope=scope, client_id=client_id, client_secret=client_secret)
        print("The response of AccessTokenApi->generate_access_token:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccessTokenApi->generate_access_token: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.moneykit.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccessTokenApi* | [**generate_access_token**](docs/AccessTokenApi.md#generate_access_token) | **POST** /auth/token | /auth/token
*AccessTokenApi* | [**get_well_known_jwks**](docs/AccessTokenApi.md#get_well_known_jwks) | **GET** /.well-known/jwks.json | JSON Web Key Set
*AccessTokenApi* | [**instrospect_client**](docs/AccessTokenApi.md#instrospect_client) | **GET** /auth/introspect | /auth/introspect
*AccountNumbersApi* | [**get_account_numbers**](docs/AccountNumbersApi.md#get_account_numbers) | **GET** /links/{id}/accounts/numbers | /links/{id}/accounts/numbers
*AccountsApi* | [**get_account**](docs/AccountsApi.md#get_account) | **GET** /links/{id}/accounts/{account_id} | /links/{id}/accounts/{account_id}
*AccountsApi* | [**get_account_numbers**](docs/AccountsApi.md#get_account_numbers) | **GET** /links/{id}/accounts/numbers | /links/{id}/accounts/numbers
*AccountsApi* | [**get_accounts**](docs/AccountsApi.md#get_accounts) | **GET** /links/{id}/accounts | /links/{id}/accounts
*AccountsApi* | [**get_user_accounts**](docs/AccountsApi.md#get_user_accounts) | **GET** /users/{id}/accounts | /users/{id}/accounts
*IdentityApi* | [**get_identities**](docs/IdentityApi.md#get_identities) | **GET** /links/{id}/identity | /links/{id}/identity
*InstitutionsApi* | [**get_institution**](docs/InstitutionsApi.md#get_institution) | **GET** /institutions/{institution_id} | /institutions/{institution_id}
*InstitutionsApi* | [**get_institutions**](docs/InstitutionsApi.md#get_institutions) | **GET** /institutions | /institutions
*LinkSessionApi* | [**create_link_session**](docs/LinkSessionApi.md#create_link_session) | **POST** /link-session | /link-session
*LinkSessionApi* | [**exchange_token**](docs/LinkSessionApi.md#exchange_token) | **POST** /link-session/exchange-token | /link-session/exchange-token
*LinksApi* | [**disconnect**](docs/LinksApi.md#disconnect) | **DELETE** /links/{id} | /links/{id}
*LinksApi* | [**get_link**](docs/LinksApi.md#get_link) | **GET** /links/{id} | /links/{id}
*LinksApi* | [**get_user_links**](docs/LinksApi.md#get_user_links) | **GET** /users/{id}/links | /users/{id}/links
*LinksApi* | [**reset_login**](docs/LinksApi.md#reset_login) | **POST** /links/{id}/reset | Force a \&quot;relink required\&quot; state on a link (Test only).
*LinksApi* | [**update_link**](docs/LinksApi.md#update_link) | **PATCH** /links/{id} | /links/{id}
*ProductsApi* | [**refresh_products**](docs/ProductsApi.md#refresh_products) | **POST** /links/{id}/products | /links/{id}/products
*TransactionsApi* | [**get_transactions**](docs/TransactionsApi.md#get_transactions) | **GET** /links/{id}/transactions | /links/{id}/transactions
*TransactionsApi* | [**get_transactions_diff**](docs/TransactionsApi.md#get_transactions_diff) | **GET** /links/{id}/transactions/sync | /links/{id}/transactions/sync
*TransactionsApi* | [**get_user_transactions**](docs/TransactionsApi.md#get_user_transactions) | **GET** /users/{id}/transactions | /users/{id}/transactions
*UsersApi* | [**get_user_accounts**](docs/UsersApi.md#get_user_accounts) | **GET** /users/{id}/accounts | /users/{id}/accounts
*UsersApi* | [**get_user_links**](docs/UsersApi.md#get_user_links) | **GET** /users/{id}/links | /users/{id}/links
*UsersApi* | [**get_user_transactions**](docs/UsersApi.md#get_user_transactions) | **GET** /users/{id}/transactions | /users/{id}/transactions
*WebhooksApi* | [**trigger_test_link_webhook_event**](docs/WebhooksApi.md#trigger_test_link_webhook_event) | **POST** /webhooks/test/link/{id} | Trigger a test webhook event for a link (Sandbox only).


## Documentation For Models

 - [APIErrorAuthExpiredAccessTokenResponse](docs/APIErrorAuthExpiredAccessTokenResponse.md)
 - [APIErrorAuthUnauthorizedResponse](docs/APIErrorAuthUnauthorizedResponse.md)
 - [APIErrorRateLimitExceededResponse](docs/APIErrorRateLimitExceededResponse.md)
 - [Account](docs/Account.md)
 - [AccountBalances](docs/AccountBalances.md)
 - [AccountGroup](docs/AccountGroup.md)
 - [AccountIdentity](docs/AccountIdentity.md)
 - [AccountNumbers](docs/AccountNumbers.md)
 - [AccountNumbersLinkProduct](docs/AccountNumbersLinkProduct.md)
 - [AccountNumbersProductSettings](docs/AccountNumbersProductSettings.md)
 - [AccountWithAccountNumbers](docs/AccountWithAccountNumbers.md)
 - [AccountsLinkProduct](docs/AccountsLinkProduct.md)
 - [AchNumber](docs/AchNumber.md)
 - [Address](docs/Address.md)
 - [BacsNumber](docs/BacsNumber.md)
 - [BasicAccountDetails](docs/BasicAccountDetails.md)
 - [Country](docs/Country.md)
 - [CreateLinkSessionRequest](docs/CreateLinkSessionRequest.md)
 - [CreateLinkSessionResponse](docs/CreateLinkSessionResponse.md)
 - [Currency](docs/Currency.md)
 - [CursorPagination](docs/CursorPagination.md)
 - [CustomerApp](docs/CustomerApp.md)
 - [EftNumber](docs/EftNumber.md)
 - [Email](docs/Email.md)
 - [ExchangeTokenRequest](docs/ExchangeTokenRequest.md)
 - [ExchangeTokenResponse](docs/ExchangeTokenResponse.md)
 - [GenerateAccessTokenResponse](docs/GenerateAccessTokenResponse.md)
 - [GetAccountNumbersResponse](docs/GetAccountNumbersResponse.md)
 - [GetAccountResponse](docs/GetAccountResponse.md)
 - [GetAccountsResponse](docs/GetAccountsResponse.md)
 - [GetInstitutionsResponse](docs/GetInstitutionsResponse.md)
 - [GetTransactionsResponse](docs/GetTransactionsResponse.md)
 - [GetUserAccountsResponse](docs/GetUserAccountsResponse.md)
 - [GetUserLinksResponse](docs/GetUserLinksResponse.md)
 - [GetUserTransactionsResponse](docs/GetUserTransactionsResponse.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [IdentityLinkProduct](docs/IdentityLinkProduct.md)
 - [IdentityProductSettings](docs/IdentityProductSettings.md)
 - [IdentityResponse](docs/IdentityResponse.md)
 - [Institution](docs/Institution.md)
 - [InstitutionErrorNotFoundResponse](docs/InstitutionErrorNotFoundResponse.md)
 - [InternationalNumber](docs/InternationalNumber.md)
 - [IntrospectClientResponse](docs/IntrospectClientResponse.md)
 - [InvestmentsProductSettings](docs/InvestmentsProductSettings.md)
 - [JWKSet](docs/JWKSet.md)
 - [LinkCommon](docs/LinkCommon.md)
 - [LinkErrorBadConfigResponse](docs/LinkErrorBadConfigResponse.md)
 - [LinkErrorBadStateResponse](docs/LinkErrorBadStateResponse.md)
 - [LinkErrorDeletedResponse](docs/LinkErrorDeletedResponse.md)
 - [LinkErrorForbiddenActionResponse](docs/LinkErrorForbiddenActionResponse.md)
 - [LinkErrorNotFoundResponse](docs/LinkErrorNotFoundResponse.md)
 - [LinkErrorUnauthorizedAccessResponse](docs/LinkErrorUnauthorizedAccessResponse.md)
 - [LinkPermissionScope](docs/LinkPermissionScope.md)
 - [LinkPermissions](docs/LinkPermissions.md)
 - [LinkProducts](docs/LinkProducts.md)
 - [LinkResponse](docs/LinkResponse.md)
 - [LinkSessionCustomerUser](docs/LinkSessionCustomerUser.md)
 - [LinkSessionCustomerUserEmail](docs/LinkSessionCustomerUserEmail.md)
 - [LinkSessionCustomerUserPhone](docs/LinkSessionCustomerUserPhone.md)
 - [LinkSessionErrorForbiddenConfigResponse](docs/LinkSessionErrorForbiddenConfigResponse.md)
 - [LinkSessionErrorInvalidTokenExchange](docs/LinkSessionErrorInvalidTokenExchange.md)
 - [LinkSessionSettingOverrides](docs/LinkSessionSettingOverrides.md)
 - [LinkState](docs/LinkState.md)
 - [LinkStateChangedWebhook](docs/LinkStateChangedWebhook.md)
 - [MoneyKitConnectFeatures](docs/MoneyKitConnectFeatures.md)
 - [Owner](docs/Owner.md)
 - [PhoneNumber](docs/PhoneNumber.md)
 - [PhoneNumberType](docs/PhoneNumberType.md)
 - [Product](docs/Product.md)
 - [ProductsSettings](docs/ProductsSettings.md)
 - [Provider](docs/Provider.md)
 - [PublicLinkError](docs/PublicLinkError.md)
 - [RefreshProductsRequest](docs/RefreshProductsRequest.md)
 - [RequestedLinkPermission](docs/RequestedLinkPermission.md)
 - [Response401DisconnectLinksIdDelete](docs/Response401DisconnectLinksIdDelete.md)
 - [Response401ExchangeTokenLinkSessionExchangeTokenPost](docs/Response401ExchangeTokenLinkSessionExchangeTokenPost.md)
 - [Response401GetAccountLinksIdAccountsAccountIdGet](docs/Response401GetAccountLinksIdAccountsAccountIdGet.md)
 - [Response401GetAccountNumbersLinksIdAccountsNumbersGet](docs/Response401GetAccountNumbersLinksIdAccountsNumbersGet.md)
 - [Response401GetAccountsLinksIdAccountsGet](docs/Response401GetAccountsLinksIdAccountsGet.md)
 - [Response401GetIdentitiesLinksIdIdentityGet](docs/Response401GetIdentitiesLinksIdIdentityGet.md)
 - [Response401GetInstitutionInstitutionsInstitutionIdGet](docs/Response401GetInstitutionInstitutionsInstitutionIdGet.md)
 - [Response401GetInstitutionsInstitutionsGet](docs/Response401GetInstitutionsInstitutionsGet.md)
 - [Response401GetLinkLinksIdGet](docs/Response401GetLinkLinksIdGet.md)
 - [Response401GetTransactionsDiffLinksIdTransactionsSyncGet](docs/Response401GetTransactionsDiffLinksIdTransactionsSyncGet.md)
 - [Response401GetTransactionsLinksIdTransactionsGet](docs/Response401GetTransactionsLinksIdTransactionsGet.md)
 - [Response401GetUserAccountsUsersIdAccountsGet](docs/Response401GetUserAccountsUsersIdAccountsGet.md)
 - [Response401GetUserLinksUsersIdLinksGet](docs/Response401GetUserLinksUsersIdLinksGet.md)
 - [Response401GetUserTransactionsUsersIdTransactionsGet](docs/Response401GetUserTransactionsUsersIdTransactionsGet.md)
 - [Response401GetWellKnownJwksWellKnownJwksJsonGet](docs/Response401GetWellKnownJwksWellKnownJwksJsonGet.md)
 - [Response401InstrospectClientAuthIntrospectGet](docs/Response401InstrospectClientAuthIntrospectGet.md)
 - [Response401RefreshProductsLinksIdProductsPost](docs/Response401RefreshProductsLinksIdProductsPost.md)
 - [Response401ResetLoginLinksIdResetPost](docs/Response401ResetLoginLinksIdResetPost.md)
 - [Response401TriggerTestLinkWebhookEventWebhooksTestLinkIdPost](docs/Response401TriggerTestLinkWebhookEventWebhooksTestLinkIdPost.md)
 - [Response401UpdateLinkLinksIdPatch](docs/Response401UpdateLinkLinksIdPatch.md)
 - [Transaction](docs/Transaction.md)
 - [TransactionDiff](docs/TransactionDiff.md)
 - [TransactionSyncResponse](docs/TransactionSyncResponse.md)
 - [TransactionType](docs/TransactionType.md)
 - [TransactionTypeFilter](docs/TransactionTypeFilter.md)
 - [TransactionsLinkProduct](docs/TransactionsLinkProduct.md)
 - [TransactionsProductSettings](docs/TransactionsProductSettings.md)
 - [UpdateLinkRequest](docs/UpdateLinkRequest.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocationInner](docs/ValidationErrorLocationInner.md)
 - [WebhookLinkTestEvent](docs/WebhookLinkTestEvent.md)
 - [WebhookTestLinkRequest](docs/WebhookTestLinkRequest.md)
 - [WebhookTestLinkResponse](docs/WebhookTestLinkResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="OAuth2ClientCredentials"></a>
### OAuth2ClientCredentials

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **link_session:create**: Client can create a Link Session for Connect SDKs
 - **link_session:tags:moneykit_reserved**: Client can use Link tags that contain reserved MoneyKit prefixes
 - **link_session:features:issue_reporter**: Client can enable in-sdk issue reporter on a Link Session
 - **link_session:features:bug_reporter**: Client can enable in-sdk (internal QA) bug reporter on a Link Session
 - **link_session:features:money_id**: Client can enable in-sdk Money ID login/registration on a Link Session
 - **link_session:features:device_verification**: Client can enable in-sdk device verification (via Prove)
 - **link_session:features:provider_sandbox_institutions**: Client can select non-MoneyKit institutions in sandbox
 - **link_session:features:simulate_provider_error**: Client can force providers to fail during the link flow
 - **link:data:read**: Client can read all data associated with a Link (accounts, transactions, auth, identity etc)
 - **link:data:refresh**: Client can trigger a manual refresh of data associated with a Link
 - **link:delete**: Client can delete a Link
 - **link:product:investments**: Client can access investments products
 - **institutions:read**: Client can fetch institutions
 - **institutions:assets:read**: Client can include assets when fetching institutions
 - **api_compatibility:plaid**: Client can access Plaid compatible API layer

<a id="HTTPBasic"></a>
### HTTPBasic

- **Type**: HTTP basic authentication


## Author




